package com.ruoyi.mall.service.impl;

import java.util.List;

import com.ruoyi.mall.domain.Vo.SubjectVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallSubjectClassMapper;
import com.ruoyi.mall.domain.MallSubjectClass;
import com.ruoyi.mall.service.IMallSubjectClassService;

import javax.annotation.Resource;

/**
 * 学科Service业务层处理
 *
 * @author ruoyi
 * @date 2023-10-27
 */
@Service
public class MallSubjectClassServiceImpl implements IMallSubjectClassService
{
    @Resource
    private MallSubjectClassMapper mallSubjectClassMapper;

    /**
     * 查询学科
     *
     * @param subjectId 学科主键
     * @return 学科
     */
    @Override
    public MallSubjectClass selectMallSubjectClassBySubjectId(Long subjectId)
    {
        return mallSubjectClassMapper.selectMallSubjectClassBySubjectId(subjectId);
    }

    /**
     * 查询学科列表
     *
     * @param mallSubjectClass 学科
     * @return 学科
     */
    @Override
    public List<MallSubjectClass> selectMallSubjectClassList(MallSubjectClass mallSubjectClass)
    {
        return mallSubjectClassMapper.selectMallSubjectClassList(mallSubjectClass);
    }

    /**
     * 新增学科
     *
     * @param mallSubjectClass 学科
     * @return 结果
     */
    @Override
    public int insertMallSubjectClass(MallSubjectClass mallSubjectClass)
    {
        return mallSubjectClassMapper.insertMallSubjectClass(mallSubjectClass);
    }

    /**
     * 修改学科
     *
     * @param mallSubjectClass 学科
     * @return 结果
     */
    @Override
    public int updateMallSubjectClass(MallSubjectClass mallSubjectClass)
    {
        return mallSubjectClassMapper.updateMallSubjectClass(mallSubjectClass);
    }

    /**
     * 批量删除学科
     *
     * @param subjectIds 需要删除的学科主键
     * @return 结果
     */
    @Override
    public int deleteMallSubjectClassBySubjectIds(Long[] subjectIds)
    {
        return mallSubjectClassMapper.deleteMallSubjectClassBySubjectIds(subjectIds);
    }

    /**
     * 删除学科信息
     *
     * @param subjectId 学科主键
     * @return 结果
     */
    @Override
    public int deleteMallSubjectClassBySubjectId(Long subjectId)
    {
        return mallSubjectClassMapper.deleteMallSubjectClassBySubjectId(subjectId);
    }

    /**
     * 学科列表
     * @return 结果
     */
    @Override
    public List<SubjectVO> selectSubjectList() {
        return mallSubjectClassMapper.selectSubjectList();
    }
}
